"use client";

import React, { useEffect, useRef, useState } from "react";
import { Input, List, DotLoading, Toast } from "antd-mobile";
import { useRouter } from "next/navigation";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faAngleLeft } from "@fortawesome/free-solid-svg-icons";
import require from "@/utils/require";
import { debounce } from "@/utils/tools";
import Empty from "@/components/Empty";
const newDebounce = debounce(function (fn) {
  fn && fn();
}, 500);
export default function Search() {
  const router = useRouter();
  // 获取屏幕高度
  // const scrollHeight = 600;
  const [searchValue, setSearchValue] = useState("");
  const [loading, setLoading] = useState(false);
  const [streamers, setStreamers] = useState([]);
  const [zones, setZones] = useState([]);
  useEffect(() => {}, []);

  const isNumeric = (str) => {
    return /^\d+$/.test(str);
  };
  const getResult = async (value) => {
    console.log("searchValue", value);
    const isSearchInt = isNumeric(value);
    let api = "";
    let querryParams = "";
    if (isSearchInt) {
      api = "/api/streamer/list_ext_fuzzily_by_user_id";
      querryParams = { user_id: parseInt(value, 10) };
    } else {
      api = "/api/streamer/list_ext_fuzzily_by_name";
      querryParams = { name: value };
    }
    try {
      setLoading(true);
      const data = await require("POST", api, {
        body: {
          ...querryParams,
          offset: 0,
          limit: 20,
        },
      });
      if (data.ret === -1) {
        Toast.show({
          icon: "fail",
          content: data.msg,
          position: "top",
        });
        return;
      }
      // if (!ignore) {
      const zonesData = data.data.list.filter((item) => item.zones.length > 0);
      setStreamers(data.data.list);
      setZones(zonesData);
      // }
      setLoading(false);
    } catch (error) {
      console.error(error);
    }
  };
  return (
    <div className="">
      <div className="flex items-center p-4">
        <FontAwesomeIcon
          icon={faAngleLeft}
          size="xl"
          className="mr-3"
          onClick={() => {
            router.back();
          }}
        />
        <div className="flex items-center w-full">
          <div className="relative bg-[#FFFFFF1A] rounded-lg px-4 py-1  w-full">
            <Input
              placeholder="搜索Ta的昵称或id"
              value={searchValue}
              onChange={(val) => {
                setSearchValue((old) => {
                  let test = (e) => {
                    if (val == "") {
                      setStreamers([]);
                      setZones([]);
                      return;
                    }
                    getResult(val);
                  };
                  newDebounce(test);
                  return val;
                });
              }}
            />
            <div className="absolute top-1/2 -translate-y-1/2 right-2">
              {loading && <DotLoading />}
            </div>
          </div>
          {searchValue && (
            <p
              className="text-base whitespace-no-wrap ml-2 text-primary font-bold"
              onClick={() => {
                setSearchValue("");
              }}
            >
              清空
            </p>
          )}
        </div>
      </div>
      <List className="px-4 overflow-y-auto scrollbarBox_hidden">
        {!streamers.length && (
          <div
            className={`h-screen -mt-[57px] flex flex-col items-center justify-center`}
          >
            <Empty type="nodata" />
          </div>
        )}
        {streamers.map((item) => (
          <List.Item
            className="!p-0"
            onClick={() => router.push(`/space/${item.mid}`)}
            key={item.id}
          >
            <div className="flex items-center">
              <img
                className="flex-none w-10 h-10 rounded-full mr-2"
                src={item?.avatar?.images[0]?.urls[0]}
                alt=""
              />
              <div className="flex-1">
                <div className="flex items-center">
                  <span className="text-md mr-2 text-base text-white font-medium">
                    {item?.name}
                  </span>
                  <span className="py-0.5 px-2 ml-1 bg-[#FFFFFF1A] rounded-full text-white text-xs font-medium">
                    ID {item.user_id}
                  </span>
                </div>
                <p className="text-sm text-[#FFFFFF80]">{item?.bio}</p>
              </div>
            </div>
          </List.Item>
        ))}
      </List>
    </div>
  );
}
